==> disposable_cached_images-1.0.6.tar.gz: lib/widget/raw_image_widget.dart <==
part of disposable_cached_images;

/// [RawImage] with [BorderRadius] and [BoxShape]
class _RawImage extends RawImage {
  const _RawImage({
    required final this.addRepaintBoundary,
    required final this.shape,
    final this.borderRadius,
    required final ui.Image image,
    required final AlignmentGeometry alignment,
    required final FilterQuality filterQuality,
    required final ImageRepeat repeat,
    required final double scale,
    required final bool invertColors,
    required final bool isAntiAlias,
    required final bool matchTextDirection,
    required final Animation<double> opacity,
    required final Rect? centerSlice,
    final double? height,
    final double? width,
    final BoxFit? fit,
    final Color? color,
    final BlendMode? colorBlendMode,
    final Key? key,
  }) : super(
          image: image,
          alignment: alignment,
          opacity: opacity,
          height: height,
          centerSlice: centerSlice,
          width: width,
          fit: fit,
          filterQuality: filterQuality,
          color: color,
          repeat: repeat,
          scale: scale,
          colorBlendMode: colorBlendMode,
          invertColors: invertColors,
          isAntiAlias: isAntiAlias,
          matchTextDirection: matchTextDirection,
          key: key,
        );

  final BorderRadius? borderRadius;
  final BoxShape shape;
  final bool addRepaintBoundary;

  @override
  RenderImage createRenderObject(final BuildContext context) {
    assert(
      (!matchTextDirection && alignment is Alignment) ||
          debugCheckHasDirectionality(context),
    );
    assert(
      image?.debugGetOpenHandleStackTraces()?.isNotEmpty ?? true,
      'Creator of a RawImage disposed of the image when the RawImage still '
      'needed it.',
    );

    return _RenderImage(
      image: image!.clone(),
      borderRadius: borderRadius,
      shape: shape,
      width: width,
      height: height,
      scale: scale,
      color: color,
      opacity: opacity!,
      colorBlendMode: colorBlendMode,
      fit: fit,
      alignment: alignment,
      repeat: repeat,
      centerSlice: centerSlice,
      matchTextDirection: matchTextDirection,
      textDirection: matchTextDirection || alignment is! Alignment
          ? Directionality.of(context)
          : null,
      invertColors: invertColors,
      isAntiAlias: isAntiAlias,
      filterQuality: filterQuality,
      addRepaintBoundary: addRepaintBoundary,
    );
  }

  @override
  void updateRenderObject(
    final BuildContext context,
    final _RenderImage renderObject,
  ) {
    super.updateRenderObject(
      context,
      renderObject
        ..borderRadius = borderRadius
        ..shape = shape,
    );
  }
}

class _RenderImage extends RenderImage {
  BorderRadius? borderRadius;
  BoxShape shape;

  final bool addRepaintBoundary;

  _RenderImage({
    required this.borderRadius,
    required this.shape,
    required this.addRepaintBoundary,
    required final ui.Image image,
    final double? width,
    final double? height,
    final double scale = 1.0,
    final Color? color,
    required final Animation<double> opacity,
    final BlendMode? colorBlendMode,
    final BoxFit? fit,
    final AlignmentGeometry alignment = Alignment.center,
    final ImageRepeat repeat = ImageRepeat.noRepeat,
    final Rect? centerSlice,
    final bool matchTextDirection = false,
    final TextDirection? textDirection,
    final bool invertColors = false,
    final bool isAntiAlias = false,
    final FilterQuality filterQuality = FilterQuality.low,
  }) : super(
          alignment: alignment,
          centerSlice: centerSlice,
          color: color,
          colorBlendMode: colorBlendMode,
          filterQuality: filterQuality,
          fit: fit,
          image: image,
          matchTextDirection: matchTextDirection,
          width: width,
          height: height,
          invertColors: invertColors,
          opacity: opacity,
          isAntiAlias: isAntiAlias,
          repeat: repeat,
          scale: scale,
          textDirection: textDirection,
        );

  @override
  void paint(final PaintingContext context, final Offset offset) {
    if (shape == BoxShape.circle) {
      context.canvas.clipPath(ovalPAth(offset, size));
    } else if (borderRadius != null) {
      context.canvas.clipRRect(borderRadius!.toRRect(offset & size));
    }

    super.paint(context, offset);
  }

  @override
  bool get isRepaintBoundary => addRepaintBoundary;

  static Path ovalPAth(final Offset offset, final Size size) {
    final rect = offset & size;

    return Path()
      ..addOval(Rect.fromCircle(
        center: rect.center,
        radius: rect.shortestSide / 2.0,
      ));
  }
}

==> disposable_cached_images-1.0.8.tar.gz: lib/widget/raw_image_widget.dart <==
part of disposable_cached_images;

/// [RawImage] with [BorderRadius] and [BoxShape]
class _RawImage extends RawImage {
  const _RawImage({
    required this.addRepaintBoundary,
    required this.shape,
    this.borderRadius,
    required final super.image,
    required final super.alignment,
    required final super.filterQuality,
    required final super.repeat,
    required final super.scale,
    required final super.invertColors,
    required final super.isAntiAlias,
    required final super.matchTextDirection,
    required final super.opacity,
    required final super.centerSlice,
    final super.height,
    final super.width,
    final super.fit,
    final super.color,
    final super.colorBlendMode,
    final super.key,
  });

  final BorderRadius? borderRadius;
  final BoxShape shape;
  final bool addRepaintBoundary;

  @override
  RenderImage createRenderObject(final BuildContext context) {
    assert(
      (!matchTextDirection && alignment is Alignment) ||
          debugCheckHasDirectionality(context),
    );
    assert(
      image?.debugGetOpenHandleStackTraces()?.isNotEmpty ?? true,
      'Creator of a RawImage disposed of the image when the RawImage still '
      'needed it.',
    );

    return _RenderImage(
      image: image!.clone(),
      borderRadius: borderRadius,
      shape: shape,
      width: width,
      height: height,
      scale: scale,
      color: color,
      opacity: opacity!,
      colorBlendMode: colorBlendMode,
      fit: fit,
      alignment: alignment,
      repeat: repeat,
      centerSlice: centerSlice,
      matchTextDirection: matchTextDirection,
      textDirection: matchTextDirection || alignment is! Alignment
          ? Directionality.of(context)
          : null,
      invertColors: invertColors,
      isAntiAlias: isAntiAlias,
      filterQuality: filterQuality,
      addRepaintBoundary: addRepaintBoundary,
    );
  }

  @override
  void updateRenderObject(
    final BuildContext context,
    final _RenderImage renderObject,
  ) {
    super.updateRenderObject(
      context,
      renderObject
        ..borderRadius = borderRadius
        ..shape = shape,
    );
  }
}

class _RenderImage extends RenderImage {
  BorderRadius? borderRadius;
  BoxShape shape;

  final bool addRepaintBoundary;

  _RenderImage({
    required this.borderRadius,
    required this.shape,
    required this.addRepaintBoundary,
    required final super.image,
    final super.width,
    final super.height,
    final super.scale = 1.0,
    final super.color,
    required final super.opacity,
    final super.colorBlendMode,
    final super.fit,
    final super.alignment = Alignment.center,
    final super.repeat = ImageRepeat.noRepeat,
    final super.centerSlice,
    final super.matchTextDirection = false,
    final super.textDirection,
    final super.invertColors = false,
    final super.isAntiAlias = false,
    final super.filterQuality = FilterQuality.low,
  });

  @override
  void paint(final PaintingContext context, final Offset offset) {
    if (shape == BoxShape.circle) {
      context.canvas.clipPath(ovalPAth(offset, size));
    } else if (borderRadius != null) {
      context.canvas.clipRRect(borderRadius!.toRRect(offset & size));
    }

    super.paint(context, offset);
  }

  @override
  bool get isRepaintBoundary => addRepaintBoundary;

  static Path ovalPAth(final Offset offset, final Size size) {
    final rect = offset & size;

    return Path()
      ..addOval(Rect.fromCircle(
        center: rect.center,
        radius: rect.shortestSide / 2.0,
      ));
  }
}
